@@ -4,8 +4,8 @@
 /* -------------------------- Gammu specific ---------------------------- */
 
 /* Version of package */
-#define GAMMU_VERSION "1.37.3"
-#define GAMMU_VERSION_NUM 13703
+#define GAMMU_VERSION "1.37.91"
+#define GAMMU_VERSION_NUM 13791
 
 /* Define if want DEBUG info */
 /* #undef DEBUG */
@@ -370,14 +370,6 @@
 /* Enable Glib */
 #define Glib_FOUND
 
-/* MS Visual C++ Express 2005 warnings */
-#if _MSC_VER == 1400
-#  pragma warning( disable : 4996 4244 4333)
-#  ifndef _CRT_SECURE_CPP_OVERLOAD_STANDARD_NAMES
-#    define _CRT_SECURE_CPP_OVERLOAD_STANDARD_NAMES  1
-#  endif
-#endif
-
 /* spawnv argument type */
 /* #undef SPAWNV_ARGUMENT_IS_CONST */
 
@@ -387,9 +379,6 @@
 /* Path where locales will be installed */
 #define GAMMU_DATA_PATH "/usr/share/gammu"
 
-/* OpenCellID API key */
-#define OPENCELLID_API_KEY "2623b0e70e9fa77754a3db53f3cb6458"
-
 /* Most winapi crap can be used as well from Cygwin */
 #if defined(WIN32) || defined(__CYGWIN__)
 #define HAVE_WINDOWS_SERVICE
